@@ -30,12 +30,12 @@ It&apos;s made in PyQt4.</source>
 Está hecho en PyQt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="53"/>
+        <location filename="watchvideo/about.py" line="44"/>
         <source>Version: </source>
         <translation type="unfinished">Versión: </translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="46"/>
+        <location filename="watchvideo/about.py" line="37"/>
         <source>
 
 WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
@@ -185,242 +185,248 @@ Está hecho en PyQt4.</translation>
 <context>
     <name>Gui</name>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="444"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="463"/>
         <source>No supported services were found</source>
         <translation type="unfinished">No fue encontrado ningún servicio admitido</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="445"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="464"/>
         <source>Close</source>
         <translation type="unfinished">Cerrar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="447"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="466"/>
         <source>Currently checking: </source>
         <translation type="unfinished">Comprobando:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="534"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
         <source>Opening download directory </source>
         <translation type="unfinished">Abriendo la(s) carpeta(s) de descargas</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="534"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
         <source>with</source>
         <translation type="unfinished">con</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="113"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="130"/>
         <source>Start</source>
         <translation type="unfinished">Comenzar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="114"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="131"/>
         <source>Stop</source>
         <translation type="unfinished">Detener</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="115"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="132"/>
         <source>Remove</source>
         <translation type="unfinished">Eliminar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="116"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="133"/>
         <source>Remove and delete file</source>
         <translation type="unfinished">Eliminar y borrar los archivos</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="117"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="134"/>
         <source>Open Folder</source>
         <translation type="unfinished">Abrir Carpeta</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="118"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="135"/>
         <source>Copy original URL</source>
         <translation type="unfinished">Copiar enlace original</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="497"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="516"/>
         <source>Download Finished</source>
         <translation type="unfinished">Descarga Terminada</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="629"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="644"/>
         <source>There are still downloads active, do you really want to quit?
 (you won&apos;t be able to continue the downloads after quit)</source>
-        <translation type="unfinished">Aún existen descargas activas, desea salir?
+        <translation type="obsolete">Aún existen descargas activas, desea salir?
 (no podrá continuar las descargas después de salir)</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="437"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="456"/>
         <source>Play</source>
         <translation type="unfinished">Reproducir</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="344"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="365"/>
         <source>Ripping audio of</source>
         <translation type="unfinished">Extraendo el audio de</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="345"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="366"/>
         <source>Audio Ripped</source>
         <translation type="unfinished">Audio extraedo</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="348"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="369"/>
         <source>Converting video:</source>
         <translation type="unfinished">Convertindo el video:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="349"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="370"/>
         <source>Video Converted</source>
         <translation type="unfinished">Video Convertido</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="346"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="367"/>
         <source>Error ripping audio</source>
         <translation type="unfinished">Error al extraer el audio</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="350"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="371"/>
         <source>Error converting video</source>
         <translation type="unfinished">Error al convertir el video</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="432"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="451"/>
         <source>Download</source>
         <translation type="unfinished">Descargar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="119"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="136"/>
         <source>Play local file</source>
         <translation>Reproducir archivo local</translation>
     </message>
+    <message>
+        <location filename="watchvideo/watchvideo_gui.py" line="649"/>
+        <source>There are still some tasks active, do you really want to quit?
+(you won&apos;t be able to continue them after quitting)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="watchvideo/ui_main.py" line="125"/>
+        <location filename="watchvideo/ui_main.py" line="174"/>
         <source>File</source>
         <translation type="unfinished">Archivo</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="126"/>
+        <location filename="watchvideo/ui_main.py" line="175"/>
         <source>Edit</source>
         <translation type="unfinished">Editar</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="127"/>
+        <location filename="watchvideo/ui_main.py" line="176"/>
         <source>Help</source>
         <translation type="unfinished">Ayuda</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="130"/>
+        <location filename="watchvideo/ui_main.py" line="179"/>
         <source>Add Videos</source>
         <translation type="unfinished">Añadir videos</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="131"/>
+        <location filename="watchvideo/ui_main.py" line="180"/>
         <source>Add one or more links to download or play directly in your favorite mediaplayer.</source>
         <translation type="unfinished">Añadir uno o más enlaces para descargar o reproducir directamente en tu reproductor multimedia favorito.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="132"/>
+        <location filename="watchvideo/ui_main.py" line="181"/>
         <source>Search Browser</source>
         <translation type="unfinished">Buscar en Navegador</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="134"/>
+        <location filename="watchvideo/ui_main.py" line="183"/>
         <source>Clear Completed</source>
         <translation type="unfinished">Limpiar completados</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="135"/>
+        <location filename="watchvideo/ui_main.py" line="184"/>
         <source>About</source>
         <translation type="unfinished">Acerca de</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="136"/>
+        <location filename="watchvideo/ui_main.py" line="185"/>
         <source>Preferences</source>
         <translation type="unfinished">Preferencias</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="137"/>
+        <location filename="watchvideo/ui_main.py" line="186"/>
         <source>Quit</source>
         <translation type="unfinished">Salir</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="123"/>
+        <location filename="watchvideo/ui_main.py" line="172"/>
         <source>Speed</source>
         <translation type="unfinished">Velocidad</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="129"/>
+        <location filename="watchvideo/ui_main.py" line="178"/>
         <source>Shortcut to get the links from the clipboard</source>
         <translation type="unfinished">Atajo para obtener los enlaces del portapapeles</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="133"/>
+        <location filename="watchvideo/ui_main.py" line="182"/>
         <source>Searches open windows and tabs in your browser for flash videos (only Firefox and derivatives are suported)</source>
         <translation type="unfinished">Busca en ventanas y pestañas abiertas en tu navegador por videos en flash (sólo Firefox y derivados son soportados)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="138"/>
+        <location filename="watchvideo/ui_main.py" line="187"/>
         <source>Clipboard</source>
         <translation type="unfinished">Portapapeles</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="139"/>
+        <location filename="watchvideo/ui_main.py" line="188"/>
         <source>Fetch link from the clipboard</source>
         <translation type="unfinished">Buscar enlaces del portapapeles</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="140"/>
+        <location filename="watchvideo/ui_main.py" line="189"/>
         <source>Play</source>
         <translation type="unfinished">Reproducir</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="141"/>
+        <location filename="watchvideo/ui_main.py" line="190"/>
         <source>Shortcut to play the video(s) from the url(s) on the clipboard</source>
         <translation type="unfinished">Atajo para reproducir los videos de los urls en el portapapeles</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="143"/>
+        <location filename="watchvideo/ui_main.py" line="192"/>
         <source>Shortcut to download the video(s) from the url(s) on the clipboard</source>
         <translation type="unfinished">Atajo para descargar los videos de los urls en el portapapeles</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="142"/>
+        <location filename="watchvideo/ui_main.py" line="191"/>
         <source>Download</source>
         <translation type="unfinished">Descargar</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="120"/>
+        <location filename="watchvideo/ui_main.py" line="169"/>
         <source>Title</source>
         <translation type="unfinished">Título</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="121"/>
+        <location filename="watchvideo/ui_main.py" line="170"/>
         <source>Size</source>
         <translation type="unfinished">Tamaño</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="122"/>
+        <location filename="watchvideo/ui_main.py" line="171"/>
         <source>Progress</source>
         <translation type="unfinished">Progreso</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="124"/>
+        <location filename="watchvideo/ui_main.py" line="173"/>
         <source>Time Left</source>
         <translation type="unfinished">Tiempo Restante</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="119"/>
+        <location filename="watchvideo/ui_main.py" line="168"/>
         <source>WatchVideo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="128"/>
+        <location filename="watchvideo/ui_main.py" line="177"/>
         <source>toolBar</source>
         <translation type="unfinished"></translation>
     </message>
@@ -428,12 +434,12 @@ Está hecho en PyQt4.</translation>
 <context>
     <name>Preferences</name>
     <message>
-        <location filename="watchvideo/preferences.py" line="169"/>
+        <location filename="watchvideo/preferences.py" line="183"/>
         <source>Media Player</source>
         <translation>Reproductor Multimedia</translation>
     </message>
     <message>
-        <location filename="watchvideo/preferences.py" line="169"/>
+        <location filename="watchvideo/preferences.py" line="183"/>
         <source>Given media player is not valid</source>
         <translation>El reproductor multimedia elegido no es válido</translation>
     </message>
@@ -441,12 +447,12 @@ Está hecho en PyQt4.</translation>
 <context>
     <name>PreferencesWindow</name>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="169"/>
+        <location filename="watchvideo/ui_preferences.py" line="182"/>
         <source>Preferences</source>
         <translation type="unfinished">Preferencias</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="170"/>
+        <location filename="watchvideo/ui_preferences.py" line="184"/>
         <source>Default media player:</source>
         <translation type="unfinished">Reproductor multimedia por defecto:</translation>
     </message>
@@ -461,42 +467,42 @@ Está hecho en PyQt4.</translation>
         <translation type="obsolete">Guardar permanentemente (las URLs seran guardadas en el disco duro)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="173"/>
+        <location filename="watchvideo/ui_preferences.py" line="187"/>
         <source>Default download folder:</source>
         <translation type="unfinished">Carpeta de descargas por defecto:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="175"/>
+        <location filename="watchvideo/ui_preferences.py" line="189"/>
         <source>Default action after download:</source>
         <translation type="unfinished">Acción por defecto después de la descarga:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="176"/>
+        <location filename="watchvideo/ui_preferences.py" line="190"/>
         <source>Do Nothing</source>
         <translation type="unfinished">No hacer nada</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="177"/>
+        <location filename="watchvideo/ui_preferences.py" line="191"/>
         <source>Play</source>
         <translation type="unfinished">Reproducir</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="178"/>
+        <location filename="watchvideo/ui_preferences.py" line="192"/>
         <source>Convert to Ogg/Vorbis (Audio)</source>
         <translation type="unfinished">Convertir a Ogg/Vorbis (Audio)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="179"/>
+        <location filename="watchvideo/ui_preferences.py" line="193"/>
         <source>Convert to Ogg/Theora (Video)</source>
         <translation type="unfinished">Convertir a Ogg/Theora (Video)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="180"/>
+        <location filename="watchvideo/ui_preferences.py" line="194"/>
         <source>Rip Audio</source>
         <translation type="unfinished">Extraer audio del video</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="184"/>
+        <location filename="watchvideo/ui_preferences.py" line="198"/>
         <source>Download Options</source>
         <translation type="unfinished">Opciones de descarga</translation>
     </message>
@@ -511,22 +517,22 @@ Está hecho en PyQt4.</translation>
         <translation type="obsolete">Baja calidad</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="190"/>
+        <location filename="watchvideo/ui_preferences.py" line="204"/>
         <source>Video Quality</source>
         <translation type="unfinished">Calidad del video</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="191"/>
+        <location filename="watchvideo/ui_preferences.py" line="205"/>
         <source>Notification Messages</source>
         <translation type="unfinished">Mensajes de notificación</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="192"/>
+        <location filename="watchvideo/ui_preferences.py" line="206"/>
         <source>The download ends successfully.</source>
         <translation type="unfinished">La descarga terminó con éxito.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="193"/>
+        <location filename="watchvideo/ui_preferences.py" line="207"/>
         <source>Show a notification message when:</source>
         <translation>Mostrar una notificación cuando:</translation>
     </message>
@@ -536,64 +542,64 @@ Está hecho en PyQt4.</translation>
         <translation type="obsolete">La descarga falla.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="198"/>
+        <location filename="watchvideo/ui_preferences.py" line="212"/>
         <source>Notifications</source>
-        <translation type="unfinished">Notificaciones</translation>
+        <translation>Notificaciones</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="195"/>
+        <location filename="watchvideo/ui_preferences.py" line="209"/>
         <source>If you want to use your system&apos;s default way to popup messages you can install &apos;python-notify&apos;. 
 In case python-notify isn&apos;t installed, WatchVideo uses baloon tooltips on the tray icon provided by Qt4.</source>
         <translation>Si quieres usar la forma de mostrar mensajens por defecto de tu sistema puedes instalar &apos;python-notify&apos;. 
 Si python-notify no estuvier instalado, WatchVideo usa tooltips en la área de notificación, providenciados por Qt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="197"/>
+        <location filename="watchvideo/ui_preferences.py" line="211"/>
         <source>Note:</source>
         <translation>Nota:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="174"/>
+        <location filename="watchvideo/ui_preferences.py" line="188"/>
         <source>...</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="172"/>
+        <location filename="watchvideo/ui_preferences.py" line="186"/>
         <source>General</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="181"/>
+        <location filename="watchvideo/ui_preferences.py" line="195"/>
         <source>When double-clicking a completed download:</source>
         <translation>Cuando se ejecuta un doble click en la descarga completada:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="182"/>
+        <location filename="watchvideo/ui_preferences.py" line="196"/>
         <source>Play Local File</source>
         <translation>Reproducir Archivo Local</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <location filename="watchvideo/ui_preferences.py" line="197"/>
         <source>Open Folder</source>
         <translation>Abrir Carpeta</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="185"/>
+        <location filename="watchvideo/ui_preferences.py" line="199"/>
         <source>Website</source>
         <translation>Sítio Web</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="187"/>
+        <location filename="watchvideo/ui_preferences.py" line="201"/>
         <source>All High Quality</source>
         <translation>Todos Alta Calidad</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="188"/>
+        <location filename="watchvideo/ui_preferences.py" line="202"/>
         <source>All low quality</source>
         <translation>Todos Baja Calidad</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="189"/>
+        <location filename="watchvideo/ui_preferences.py" line="203"/>
         <source>Mixed</source>
         <translation>Mezclado</translation>
     </message>
@@ -603,9 +609,14 @@ Si python-notify no estuvier instalado, WatchVideo usa tooltips en la área de n
         <translation type="obsolete">Nota: Esto es un trabajo en progreso por eso muchos plugins acá listados todavia no tienen soporte para alta calidad.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="194"/>
+        <location filename="watchvideo/ui_preferences.py" line="208"/>
         <source>An error occurs.</source>
-        <translation type="unfinished">Sucede un error.</translation>
+        <translation>Sucede un error.</translation>
+    </message>
+    <message>
+        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <source>Use built-in player.</source>
+        <translation>Usar reproductor integrado.</translation>
     </message>
 </context>
 </TS>
