@@ -30,7 +30,7 @@ It&apos;s made in PyQt4.</source>
 Korzysta z PyQt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="53"/>
+        <location filename="watchvideo/about.py" line="44"/>
         <source>Version: </source>
         <translation>Wersja:</translation>
     </message>
@@ -42,7 +42,7 @@ It&apos;s made in PyQt4.</source>
 Korzysta z PyQt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="46"/>
+        <location filename="watchvideo/about.py" line="37"/>
         <source>
 
 WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
@@ -184,27 +184,27 @@ It&apos;s made in PyQt4.</source>
 <context>
     <name>Gui</name>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="444"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="463"/>
         <source>No supported services were found</source>
         <translation>Nie odnaleziono wspieranych usług</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="445"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="464"/>
         <source>Close</source>
         <translation>Zamknij</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="447"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="466"/>
         <source>Currently checking: </source>
         <translation>Aktualnie sprawdzane:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="534"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
         <source>Opening download directory </source>
         <translation>Otwieranie katalogu pobierania</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="534"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
         <source>with</source>
         <translation>z</translation>
     </message>
@@ -219,217 +219,223 @@ It&apos;s made in PyQt4.</source>
         <translation type="obsolete">odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="113"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="130"/>
         <source>Start</source>
         <translation>Rozpocznij</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="114"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="131"/>
         <source>Stop</source>
         <translation>Zakończ</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="115"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="132"/>
         <source>Remove</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="116"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="133"/>
         <source>Remove and delete file</source>
         <translation>Usuń wraz z plikiem</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="117"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="134"/>
         <source>Open Folder</source>
         <translation>Otwórz katalog</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="118"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="135"/>
         <source>Copy original URL</source>
         <translation>Skopiuj oryginalny URL</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="497"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="516"/>
         <source>Download Finished</source>
         <translation>Pobieranie zakończone</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="629"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="644"/>
         <source>There are still downloads active, do you really want to quit?
 (you won&apos;t be able to continue the downloads after quit)</source>
-        <translation>Pliki są nadal pobierane, czy chcesz je przerwać?
+        <translation type="obsolete">Pliki są nadal pobierane, czy chcesz je przerwać?
 (nie zostaną wznowione po ponownym uruchomieniu programu)</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="437"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="456"/>
         <source>Play</source>
         <translation>Odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="344"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="365"/>
         <source>Ripping audio of</source>
         <translation>Pobieranie dźwięku z</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="345"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="366"/>
         <source>Audio Ripped</source>
         <translation>Dźwięk pobrany</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="348"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="369"/>
         <source>Converting video:</source>
         <translation>Konwertowanie filmu:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="349"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="370"/>
         <source>Video Converted</source>
         <translation>Film skonwertowany</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="432"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="451"/>
         <source>Download</source>
         <translation>Pobierz</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="346"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="367"/>
         <source>Error ripping audio</source>
         <translation>Błąd pobierania dźwięku</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="350"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="371"/>
         <source>Error converting video</source>
         <translation>Błąd konwersji filmu</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="119"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="136"/>
         <source>Play local file</source>
         <translation>Odtwórz plik lokalny</translation>
     </message>
+    <message>
+        <location filename="watchvideo/watchvideo_gui.py" line="649"/>
+        <source>There are still some tasks active, do you really want to quit?
+(you won&apos;t be able to continue them after quitting)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="watchvideo/ui_main.py" line="119"/>
+        <location filename="watchvideo/ui_main.py" line="168"/>
         <source>WatchVideo</source>
         <translation>WatchVideo</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="120"/>
+        <location filename="watchvideo/ui_main.py" line="169"/>
         <source>Title</source>
         <translation>Tytuł</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="121"/>
+        <location filename="watchvideo/ui_main.py" line="170"/>
         <source>Size</source>
         <translation>Rozmiar</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="122"/>
+        <location filename="watchvideo/ui_main.py" line="171"/>
         <source>Progress</source>
         <translation>Postęp</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="123"/>
+        <location filename="watchvideo/ui_main.py" line="172"/>
         <source>Speed</source>
         <translation>Prędkość</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="124"/>
+        <location filename="watchvideo/ui_main.py" line="173"/>
         <source>Time Left</source>
         <translation>Pozostały czas</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="125"/>
+        <location filename="watchvideo/ui_main.py" line="174"/>
         <source>File</source>
         <translation>Plik</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="126"/>
+        <location filename="watchvideo/ui_main.py" line="175"/>
         <source>Edit</source>
         <translation>Edycja</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="127"/>
+        <location filename="watchvideo/ui_main.py" line="176"/>
         <source>Help</source>
         <translation>Pomoc</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="128"/>
+        <location filename="watchvideo/ui_main.py" line="177"/>
         <source>toolBar</source>
         <translation>Pasek narzędzi</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="129"/>
+        <location filename="watchvideo/ui_main.py" line="178"/>
         <source>Shortcut to get the links from the clipboard</source>
         <translation>Skrót do wstawienia linków z schowka</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="130"/>
+        <location filename="watchvideo/ui_main.py" line="179"/>
         <source>Add Videos</source>
         <translation>Dodaj filmy</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="131"/>
+        <location filename="watchvideo/ui_main.py" line="180"/>
         <source>Add one or more links to download or play directly in your favorite mediaplayer.</source>
         <translation>Dodaj jeden lub więcej linków do pobrania lub otworzenia w Twoim ulubionym odtwarzaczu.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="132"/>
+        <location filename="watchvideo/ui_main.py" line="181"/>
         <source>Search Browser</source>
         <translation>Znajdź z przeglądarki</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="133"/>
+        <location filename="watchvideo/ui_main.py" line="182"/>
         <source>Searches open windows and tabs in your browser for flash videos (only Firefox and derivatives are suported)</source>
         <translation>Szuka filmów używających Flash w otwartych oknach i kartach przeglądarki opartej na Firefoksie</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="134"/>
+        <location filename="watchvideo/ui_main.py" line="183"/>
         <source>Clear Completed</source>
         <translation>Czyszczenie zakończone</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="135"/>
+        <location filename="watchvideo/ui_main.py" line="184"/>
         <source>About</source>
         <translation>O programie</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="136"/>
+        <location filename="watchvideo/ui_main.py" line="185"/>
         <source>Preferences</source>
         <translation>Ustawienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="137"/>
+        <location filename="watchvideo/ui_main.py" line="186"/>
         <source>Quit</source>
         <translation>Wyjdź</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="138"/>
+        <location filename="watchvideo/ui_main.py" line="187"/>
         <source>Clipboard</source>
         <translation>Schowek</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="139"/>
+        <location filename="watchvideo/ui_main.py" line="188"/>
         <source>Fetch link from the clipboard</source>
         <translation>Pobierz linki z schowka</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="140"/>
+        <location filename="watchvideo/ui_main.py" line="189"/>
         <source>Play</source>
         <translation>Odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="141"/>
+        <location filename="watchvideo/ui_main.py" line="190"/>
         <source>Shortcut to play the video(s) from the url(s) on the clipboard</source>
         <translation>Skrót do otworzenia filmów z URL-i w schowku</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="142"/>
+        <location filename="watchvideo/ui_main.py" line="191"/>
         <source>Download</source>
         <translation>Pobierz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="143"/>
+        <location filename="watchvideo/ui_main.py" line="192"/>
         <source>Shortcut to download the video(s) from the url(s) on the clipboard</source>
         <translation>Skrót do pobrania filmów z URL-i w schowku</translation>
     </message>
@@ -437,12 +443,12 @@ It&apos;s made in PyQt4.</source>
 <context>
     <name>Preferences</name>
     <message>
-        <location filename="watchvideo/preferences.py" line="169"/>
+        <location filename="watchvideo/preferences.py" line="183"/>
         <source>Media Player</source>
         <translation>Odtwarzacz</translation>
     </message>
     <message>
-        <location filename="watchvideo/preferences.py" line="169"/>
+        <location filename="watchvideo/preferences.py" line="183"/>
         <source>Given media player is not valid</source>
         <translation>Wybrano nieprawidłowy odtwarzacz</translation>
     </message>
@@ -450,17 +456,17 @@ It&apos;s made in PyQt4.</source>
 <context>
     <name>PreferencesWindow</name>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="169"/>
+        <location filename="watchvideo/ui_preferences.py" line="182"/>
         <source>Preferences</source>
         <translation>Ustawienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="170"/>
+        <location filename="watchvideo/ui_preferences.py" line="184"/>
         <source>Default media player:</source>
         <translation>Domyślny odtwarzacz:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="174"/>
+        <location filename="watchvideo/ui_preferences.py" line="188"/>
         <source>...</source>
         <translation>...</translation>
     </message>
@@ -475,47 +481,47 @@ It&apos;s made in PyQt4.</source>
         <translation type="obsolete">Zapisz URL-e na dysk</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="172"/>
+        <location filename="watchvideo/ui_preferences.py" line="186"/>
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="173"/>
+        <location filename="watchvideo/ui_preferences.py" line="187"/>
         <source>Default download folder:</source>
         <translation>Domyślny katalog pobierania:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="175"/>
+        <location filename="watchvideo/ui_preferences.py" line="189"/>
         <source>Default action after download:</source>
         <translation>Domyśle działanie po pobraniu:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="176"/>
+        <location filename="watchvideo/ui_preferences.py" line="190"/>
         <source>Do Nothing</source>
         <translation>Nic nie rób</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="177"/>
+        <location filename="watchvideo/ui_preferences.py" line="191"/>
         <source>Play</source>
         <translation>Odtwórz</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="178"/>
+        <location filename="watchvideo/ui_preferences.py" line="192"/>
         <source>Convert to Ogg/Vorbis (Audio)</source>
         <translation>Skonwertuj do Ogg Vorbis (dźwięk)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="179"/>
+        <location filename="watchvideo/ui_preferences.py" line="193"/>
         <source>Convert to Ogg/Theora (Video)</source>
         <translation>Skonwertuj do Ogg Theora (film)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="180"/>
+        <location filename="watchvideo/ui_preferences.py" line="194"/>
         <source>Rip Audio</source>
         <translation>Pobierz dźwięk</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="184"/>
+        <location filename="watchvideo/ui_preferences.py" line="198"/>
         <source>Download Options</source>
         <translation>Opcje pobierania</translation>
     </message>
@@ -540,22 +546,22 @@ It&apos;s made in PyQt4.</source>
         <translation type="obsolete">Blip.tv</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="190"/>
+        <location filename="watchvideo/ui_preferences.py" line="204"/>
         <source>Video Quality</source>
         <translation>Jakość filmu</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="191"/>
+        <location filename="watchvideo/ui_preferences.py" line="205"/>
         <source>Notification Messages</source>
         <translation>Powiadomienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="192"/>
+        <location filename="watchvideo/ui_preferences.py" line="206"/>
         <source>The download ends successfully.</source>
         <translation>Pobieranie zakończone z powodzeniem.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="193"/>
+        <location filename="watchvideo/ui_preferences.py" line="207"/>
         <source>Show a notification message when:</source>
         <translation>Wyświetl powiadomienie gdy:</translation>
     </message>
@@ -565,61 +571,66 @@ It&apos;s made in PyQt4.</source>
         <translation type="obsolete">Pobieranie nie powiodło się.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="198"/>
+        <location filename="watchvideo/ui_preferences.py" line="212"/>
         <source>Notifications</source>
         <translation>Powiadomienia</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="195"/>
+        <location filename="watchvideo/ui_preferences.py" line="209"/>
         <source>If you want to use your system&apos;s default way to popup messages you can install &apos;python-notify&apos;. 
 In case python-notify isn&apos;t installed, WatchVideo uses baloon tooltips on the tray icon provided by Qt4.</source>
         <translation>Jeżeli chcesz użyć systemowe powiadomienia, zainstaluj pakiet „python-notify”.
 Jeżeli nie jest on zainstalowany, to WatchVideo użyje powiadomienia z Qt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="197"/>
+        <location filename="watchvideo/ui_preferences.py" line="211"/>
         <source>Note:</source>
         <translation>Uwaga:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="181"/>
+        <location filename="watchvideo/ui_preferences.py" line="195"/>
         <source>When double-clicking a completed download:</source>
         <translation>Przy podwójnym kilknięciu pobranego pliku:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="182"/>
+        <location filename="watchvideo/ui_preferences.py" line="196"/>
         <source>Play Local File</source>
         <translation>Odtwórz plik lokalny</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <location filename="watchvideo/ui_preferences.py" line="197"/>
         <source>Open Folder</source>
         <translation>Otwórz katalog</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="185"/>
+        <location filename="watchvideo/ui_preferences.py" line="199"/>
         <source>Website</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="187"/>
+        <location filename="watchvideo/ui_preferences.py" line="201"/>
         <source>All High Quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="188"/>
+        <location filename="watchvideo/ui_preferences.py" line="202"/>
         <source>All low quality</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="189"/>
+        <location filename="watchvideo/ui_preferences.py" line="203"/>
         <source>Mixed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="194"/>
+        <location filename="watchvideo/ui_preferences.py" line="208"/>
         <source>An error occurs.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <source>Use built-in player.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
