@@ -30,12 +30,12 @@ It&apos;s made in PyQt4.</source>
 É feito em PyQt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="53"/>
+        <location filename="watchvideo/about.py" line="44"/>
         <source>Version: </source>
         <translation>Versão: </translation>
     </message>
     <message>
-        <location filename="watchvideo/about.py" line="46"/>
+        <location filename="watchvideo/about.py" line="37"/>
         <source>
 
 WatchVideo is a small application to play, download or convert videos (to Ogg) from various youtube-like sites.
@@ -51,12 +51,12 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
     <message>
         <location filename="watchvideo/ui_add_videos.py" line="161"/>
         <source>Add Videos</source>
-        <translation type="unfinished">Adiconar Vídeos</translation>
+        <translation>Adiconar Vídeos</translation>
     </message>
     <message>
         <location filename="watchvideo/ui_add_videos.py" line="162"/>
         <source>Paste link(s) here:</source>
-        <translation type="unfinished">Colar ligações aqui:</translation>
+        <translation>Colar ligações aqui:</translation>
     </message>
     <message>
         <location filename="watchvideo/ui_add_videos.py" line="136"/>
@@ -180,242 +180,248 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
 <context>
     <name>Gui</name>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="444"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="463"/>
         <source>No supported services were found</source>
         <translation>Nenhum serviço suportado foi encontrado</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="445"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="464"/>
         <source>Close</source>
         <translation>Fechar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="447"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="466"/>
         <source>Currently checking: </source>
         <translation>A verificar:  </translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="534"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
         <source>Opening download directory </source>
         <translation>A abrir a pasta de descargas </translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="534"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="553"/>
         <source>with</source>
         <translation>com</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="113"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="130"/>
         <source>Start</source>
         <translation>Iniciar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="114"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="131"/>
         <source>Stop</source>
         <translation>Parar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="115"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="132"/>
         <source>Remove</source>
         <translation>Remover</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="116"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="133"/>
         <source>Remove and delete file</source>
         <translation>Remover e apagar ficheiro</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="117"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="134"/>
         <source>Open Folder</source>
         <translation>Abrir Pasta</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="118"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="135"/>
         <source>Copy original URL</source>
         <translation>Copiar ligação original</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="497"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="516"/>
         <source>Download Finished</source>
         <translation>Descarga Terminada</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="629"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="644"/>
         <source>There are still downloads active, do you really want to quit?
 (you won&apos;t be able to continue the downloads after quit)</source>
-        <translation>Ainda existem descargas activas, deseja realmente sair?
+        <translation type="obsolete">Ainda existem descargas activas, deseja realmente sair?
 (não poderá continuar as descargas depois de sair)</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="437"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="456"/>
         <source>Play</source>
         <translation>Reproduzir</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="344"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="365"/>
         <source>Ripping audio of</source>
         <translation>A extrair áudio de</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="345"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="366"/>
         <source>Audio Ripped</source>
         <translation>Áudio Extraído</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="348"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="369"/>
         <source>Converting video:</source>
         <translation>A converter vídeo:</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="349"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="370"/>
         <source>Video Converted</source>
         <translation>Vídeo Convertido</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="432"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="451"/>
         <source>Download</source>
         <translation>Descarregar</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="346"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="367"/>
         <source>Error ripping audio</source>
         <translation>Erro ao extrair áudio</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="350"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="371"/>
         <source>Error converting video</source>
         <translation>Erro ao converter vídeo</translation>
     </message>
     <message>
-        <location filename="watchvideo/watchvideo_gui.py" line="119"/>
+        <location filename="watchvideo/watchvideo_gui.py" line="136"/>
         <source>Play local file</source>
         <translation>Reproduzir-ficheiro-local</translation>
     </message>
+    <message>
+        <location filename="watchvideo/watchvideo_gui.py" line="649"/>
+        <source>There are still some tasks active, do you really want to quit?
+(you won&apos;t be able to continue them after quitting)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="watchvideo/ui_main.py" line="125"/>
+        <location filename="watchvideo/ui_main.py" line="174"/>
         <source>File</source>
         <translation type="unfinished">Ficheiro</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="126"/>
+        <location filename="watchvideo/ui_main.py" line="175"/>
         <source>Edit</source>
         <translation type="unfinished">Editar</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="127"/>
+        <location filename="watchvideo/ui_main.py" line="176"/>
         <source>Help</source>
         <translation type="unfinished">Ajuda</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="130"/>
+        <location filename="watchvideo/ui_main.py" line="179"/>
         <source>Add Videos</source>
         <translation type="unfinished">Adicionar Vídeos</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="131"/>
+        <location filename="watchvideo/ui_main.py" line="180"/>
         <source>Add one or more links to download or play directly in your favorite mediaplayer.</source>
         <translation type="unfinished">Adicionar uma ou mais ligações para descarregar ou reproduzir directamento no seu leitor multimédia favorito.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="132"/>
+        <location filename="watchvideo/ui_main.py" line="181"/>
         <source>Search Browser</source>
         <translation type="unfinished">Pesquisar no Navegador</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="134"/>
+        <location filename="watchvideo/ui_main.py" line="183"/>
         <source>Clear Completed</source>
         <translation type="unfinished">Apagar Completos</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="135"/>
+        <location filename="watchvideo/ui_main.py" line="184"/>
         <source>About</source>
         <translation type="unfinished">Acerca</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="136"/>
+        <location filename="watchvideo/ui_main.py" line="185"/>
         <source>Preferences</source>
         <translation type="unfinished">Preferências</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="137"/>
+        <location filename="watchvideo/ui_main.py" line="186"/>
         <source>Quit</source>
         <translation type="unfinished">Sair</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="123"/>
+        <location filename="watchvideo/ui_main.py" line="172"/>
         <source>Speed</source>
         <translation type="unfinished">Velocidade</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="129"/>
+        <location filename="watchvideo/ui_main.py" line="178"/>
         <source>Shortcut to get the links from the clipboard</source>
         <translation type="unfinished">Atalho para buscar ligações da área de transferência</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="133"/>
+        <location filename="watchvideo/ui_main.py" line="182"/>
         <source>Searches open windows and tabs in your browser for flash videos (only Firefox and derivatives are suported)</source>
         <translation type="unfinished">Pesquisa por janelas e abas abertas no navegador por vídeos em flash (Apenas o Firefox ou derivados são suportados)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="138"/>
+        <location filename="watchvideo/ui_main.py" line="187"/>
         <source>Clipboard</source>
         <translation type="unfinished">Área de Transferência</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="139"/>
+        <location filename="watchvideo/ui_main.py" line="188"/>
         <source>Fetch link from the clipboard</source>
         <translation type="unfinished">Buscar ligação da área de transferência</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="140"/>
+        <location filename="watchvideo/ui_main.py" line="189"/>
         <source>Play</source>
         <translation type="unfinished">Reproduzir</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="141"/>
+        <location filename="watchvideo/ui_main.py" line="190"/>
         <source>Shortcut to play the video(s) from the url(s) on the clipboard</source>
         <translation type="unfinished">Atalho para reproduzir vídeo(s) do(s) url(s) que estão na área de transferência</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="143"/>
+        <location filename="watchvideo/ui_main.py" line="192"/>
         <source>Shortcut to download the video(s) from the url(s) on the clipboard</source>
         <translation type="unfinished">Atalho para descarregar o(s) vídeo(s) do(s) url(s) que estão na área de transferência</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="142"/>
+        <location filename="watchvideo/ui_main.py" line="191"/>
         <source>Download</source>
         <translation type="unfinished">Descarregar</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="120"/>
+        <location filename="watchvideo/ui_main.py" line="169"/>
         <source>Title</source>
         <translation type="unfinished">Título</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="121"/>
+        <location filename="watchvideo/ui_main.py" line="170"/>
         <source>Size</source>
         <translation type="unfinished">Tamanho</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="122"/>
+        <location filename="watchvideo/ui_main.py" line="171"/>
         <source>Progress</source>
         <translation type="unfinished">Progresso</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="124"/>
+        <location filename="watchvideo/ui_main.py" line="173"/>
         <source>Time Left</source>
         <translation type="unfinished">Tempo Restante</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="119"/>
+        <location filename="watchvideo/ui_main.py" line="168"/>
         <source>WatchVideo</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_main.py" line="128"/>
+        <location filename="watchvideo/ui_main.py" line="177"/>
         <source>toolBar</source>
         <translation type="unfinished"></translation>
     </message>
@@ -423,12 +429,12 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
 <context>
     <name>Preferences</name>
     <message>
-        <location filename="watchvideo/preferences.py" line="169"/>
+        <location filename="watchvideo/preferences.py" line="183"/>
         <source>Media Player</source>
         <translation>Reprodutor Multimédia</translation>
     </message>
     <message>
-        <location filename="watchvideo/preferences.py" line="169"/>
+        <location filename="watchvideo/preferences.py" line="183"/>
         <source>Given media player is not valid</source>
         <translation>O reprodutor multimédia dado não é válido</translation>
     </message>
@@ -436,12 +442,12 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
 <context>
     <name>PreferencesWindow</name>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="169"/>
+        <location filename="watchvideo/ui_preferences.py" line="182"/>
         <source>Preferences</source>
         <translation type="unfinished">Preferências</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="170"/>
+        <location filename="watchvideo/ui_preferences.py" line="184"/>
         <source>Default media player:</source>
         <translation type="unfinished">Leitor Multimédia Por Defeito:</translation>
     </message>
@@ -456,47 +462,47 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
         <translation type="obsolete">Guardar permanentemente (urls serão guardados para disco)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="172"/>
+        <location filename="watchvideo/ui_preferences.py" line="186"/>
         <source>General</source>
         <translation type="unfinished">Geral</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="173"/>
+        <location filename="watchvideo/ui_preferences.py" line="187"/>
         <source>Default download folder:</source>
         <translation type="unfinished">Pasta destino por defeito:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="175"/>
+        <location filename="watchvideo/ui_preferences.py" line="189"/>
         <source>Default action after download:</source>
         <translation type="unfinished">Acção por defeito depois de descarregar:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="176"/>
+        <location filename="watchvideo/ui_preferences.py" line="190"/>
         <source>Do Nothing</source>
         <translation type="unfinished">Nada a Fazer</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="177"/>
+        <location filename="watchvideo/ui_preferences.py" line="191"/>
         <source>Play</source>
         <translation type="unfinished">Reproduzir</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="178"/>
+        <location filename="watchvideo/ui_preferences.py" line="192"/>
         <source>Convert to Ogg/Vorbis (Audio)</source>
         <translation type="unfinished">Converter para Ogg/Vorbis (Áudio)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="179"/>
+        <location filename="watchvideo/ui_preferences.py" line="193"/>
         <source>Convert to Ogg/Theora (Video)</source>
         <translation type="unfinished">Converter para Ogg/Theora (Vídeo)</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="180"/>
+        <location filename="watchvideo/ui_preferences.py" line="194"/>
         <source>Rip Audio</source>
         <translation type="unfinished">Extrair Áudio</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="184"/>
+        <location filename="watchvideo/ui_preferences.py" line="198"/>
         <source>Download Options</source>
         <translation type="unfinished">Opções Descarga</translation>
     </message>
@@ -511,22 +517,22 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
         <translation type="obsolete">Baixa Qualidade</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="190"/>
+        <location filename="watchvideo/ui_preferences.py" line="204"/>
         <source>Video Quality</source>
         <translation type="unfinished">Qualidade de Vídeo</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="191"/>
+        <location filename="watchvideo/ui_preferences.py" line="205"/>
         <source>Notification Messages</source>
         <translation type="unfinished">Mensagens de Notificação</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="192"/>
+        <location filename="watchvideo/ui_preferences.py" line="206"/>
         <source>The download ends successfully.</source>
         <translation type="unfinished">A descarga termina com sucesso.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="193"/>
+        <location filename="watchvideo/ui_preferences.py" line="207"/>
         <source>Show a notification message when:</source>
         <translation type="unfinished">Mostrar uma mensagem de notitificação quando:</translation>
     </message>
@@ -536,59 +542,59 @@ WatchVideo é uma pequena aplicação para reproduzir, descarregar ou converter
         <translation type="obsolete">A descarga falhou.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="198"/>
+        <location filename="watchvideo/ui_preferences.py" line="212"/>
         <source>Notifications</source>
         <translation type="unfinished">Notificações</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="195"/>
+        <location filename="watchvideo/ui_preferences.py" line="209"/>
         <source>If you want to use your system&apos;s default way to popup messages you can install &apos;python-notify&apos;. 
 In case python-notify isn&apos;t installed, WatchVideo uses baloon tooltips on the tray icon provided by Qt4.</source>
-        <translation type="unfinished">Se quiser usar a forma de mostrar mensagens de notificação do seu sistema, pode instalar &apos;python-notify&apos;.
+        <translation>Se quiser usar a forma de mostrar mensagens de notificação do seu sistema, pode instalar &apos;python-notify&apos;.
 No caso do python-notify não estar instalado, WatchVideo usa tooltips na área de notificação providenciados por Qt4.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="197"/>
+        <location filename="watchvideo/ui_preferences.py" line="211"/>
         <source>Note:</source>
-        <translation type="unfinished">Nota:</translation>
+        <translation>Nota:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="174"/>
+        <location filename="watchvideo/ui_preferences.py" line="188"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="181"/>
+        <location filename="watchvideo/ui_preferences.py" line="195"/>
         <source>When double-clicking a completed download:</source>
         <translation>Ao dar duplo clique numa descarga completa:</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="182"/>
+        <location filename="watchvideo/ui_preferences.py" line="196"/>
         <source>Play Local File</source>
         <translation>Reproduzir Ficheiro Local</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <location filename="watchvideo/ui_preferences.py" line="197"/>
         <source>Open Folder</source>
         <translation>Abrir Pasta</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="185"/>
+        <location filename="watchvideo/ui_preferences.py" line="199"/>
         <source>Website</source>
         <translation>Sítio Web</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="187"/>
+        <location filename="watchvideo/ui_preferences.py" line="201"/>
         <source>All High Quality</source>
         <translation>Todos Alta Qualidade</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="188"/>
+        <location filename="watchvideo/ui_preferences.py" line="202"/>
         <source>All low quality</source>
         <translation>Todos Baixa Qualidade</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="189"/>
+        <location filename="watchvideo/ui_preferences.py" line="203"/>
         <source>Mixed</source>
         <translation>Misturado</translation>
     </message>
@@ -598,9 +604,14 @@ No caso do python-notify não estar instalado, WatchVideo usa tooltips na área
         <translation type="obsolete">Nota: Isto ainda é um trabalho em progresso por isso muitos plugins aqui listados ainda não têm suporte para alta qualidade.</translation>
     </message>
     <message>
-        <location filename="watchvideo/ui_preferences.py" line="194"/>
+        <location filename="watchvideo/ui_preferences.py" line="208"/>
         <source>An error occurs.</source>
         <translation>Ocorre um erro.</translation>
     </message>
+    <message>
+        <location filename="watchvideo/ui_preferences.py" line="183"/>
+        <source>Use built-in player.</source>
+        <translation>Usar reprodutor integrado.</translation>
+    </message>
 </context>
 </TS>
