@@ -34,7 +34,7 @@ except ImportError:
     print "manager, or download (and install) it from <http://www.riverbankcomputing.co.uk/pyqt/download.php>.\n"
     exit()
     
-from threading import Thread
+from threading import (Thread, Timer)
 import sys
 import os
 import subprocess
@@ -46,6 +46,7 @@ except ImportError:
 
 from PyQt4.QtGui import (QMenu, QAction, QIcon, QProgressBar,
                          QPushButton, QSystemTrayIcon, QComboBox, QTreeWidgetItem)
+from PyQt4.QtCore import Qt
 
 from watchvideo.ui_main import Ui_MainWindow
 from watchvideo.threads import DownloadItem, Convert
@@ -56,7 +57,8 @@ import watchvideo.constants as c
 from watchvideo import gui_utils
 from getmediumurl import Matcher
 from watchvideo.utils import is_command
-
+from player import Player
+from mplayer.qt4 import QPlayerView
 
 class Gui(QtGui.QMainWindow):
     """WatchVideo's main class."""
@@ -83,6 +85,20 @@ class Gui(QtGui.QMainWindow):
         self.videos_info = []
         self.match_url = None
         self.qaction_pressed = ""
+        self.matcher = Matcher()
+        
+        if c.HAS_MPLAYER:
+          self.verticalLayout = QtGui.QVBoxLayout()
+          self.player = Player(self)
+          self.verticalLayout.addWidget(self.player.slider)
+          self.verticalLayout.addWidget(self.player.progressbar)
+          self.ui.horizontalLayout.addLayout(self.verticalLayout)
+          QtCore.QObject.connect(self.ui.btn_play, QtCore.SIGNAL("clicked()"), self.player.play)
+          QtCore.QObject.connect(self.ui.btn_pause, QtCore.SIGNAL("clicked()"), self.player.pause)
+        else:
+          self.ui.videoWidget.setVisible(False)
+          self.ui.stackedWidget.setVisible(False)
+          self.player = None
         
         self.b_cancelSearch = None
         self.ui.tree_downloads.setColumnCount(5)
@@ -155,7 +171,7 @@ class Gui(QtGui.QMainWindow):
                                                         self.openWindow)
         QtCore.QObject.connect(self.a_play_local, QtCore.SIGNAL("triggered()"), self.play)
         #QtCore.QObject.connect(self.close, QtCore.SIGNAL("triggered()"), self.quit)
-     
+ 
      
     def onDownloadDoubleClick(self, item, pos):
         #if the download is completed we can either open the directory or play
@@ -282,9 +298,7 @@ class Gui(QtGui.QMainWindow):
                         
             point = QtGui.QCursor.pos() 
             self.menu.exec_(point)
-            
-
-
+        
         
     def addNewDownloads(self, videos):
         if not videos: 
@@ -312,9 +326,14 @@ class Gui(QtGui.QMainWindow):
                     self.timer_check_downloads.start(750)
         else: #Play
             for video in videos:
-                Thread(target=main.play, args=(video.dl_url, video.name,
-                self.settings.value('General/mediaPlayer').toString())).start()
-                
+                if self.settings.value("General/useBuiltinPlayer").toInt()[0]:  
+                    item = DownloadItem(None, video.url, video.dl_url, video.filepath, video.after_complete)
+                    self.player.loadfile(video.filepath, item)
+                else:
+                    Thread(target=main.play, args=(video.dl_url, video.name,
+                    self.settings.value('General/mediaPlayer').toString())).start()
+        
+        self.qaction_pressed = ""
         del self.videos_info [:]
 
     def afterComplete(self, download_item):
@@ -368,9 +387,9 @@ class Gui(QtGui.QMainWindow):
     def searchBrowser(self):
         session = json.loads(open(c.FIREFOX_SESSION).read().strip("()"))
         urls = []
-        matcher = Matcher()
-        regxps = [plugin.match_re for plugin in matcher.plugins.itervalues()]
-        
+        regxps = [ plugin.match_re for plugin in self.matcher.plugins.itervalues()\
+        if plugin.match_re is not None ]
+                
         #search windows and tabs open in firefox
         for window in session["windows"]:
             for tab in window["tabs"]:
@@ -378,22 +397,21 @@ class Gui(QtGui.QMainWindow):
                     try:
                         url = entry["url"]
                         for regxp in regxps:
-                            if regxp and regxp.match(url):
+                            if regxp.match(url):
                                 urls.append(url)
+                                break
+                                
                     except IndexError:
                         pass
-         
+        
+
         self.getFilesUrl(urls)
                         
 
     def getFilesUrl(self, urls):
         if self.match_url: return
         
-        urls_clean = []
-        for url in urls:
-            if url[:7] == "http://" and len(url) != len("http://"):
-                urls_clean.append(url)
-        urls = urls_clean     
+        urls = [url for url in urls if url[:7] == "http://" and len(url) != len("http://")] 
                 
         if urls:
             #add cancel button
@@ -625,14 +643,20 @@ class Gui(QtGui.QMainWindow):
                 self.show()
     
     def closeEvent(self, event):
-        if self.active_downloads or self.stopped_downloads:
+        if self.active_downloads or self.stopped_downloads or \
+        (self.player and self.player.playing):
             answer = gui_utils.confirm(self, title="Quit?",
-            msg=self.tr("There are still downloads active, do you really want to quit?" + 
-            "\n(you won't be able to continue the downloads after quit)"))
+            msg=self.tr("There are still some tasks active, do you really want to quit?" + 
+            "\n(you won't be able to continue them after quitting)"))
 
             if answer == QtGui.QMessageBox.Yes:
                 for download in self.active_downloads + self.stopped_downloads:
                     download.abort = True
+                
+                if self.player:
+                    if self.player.playing: self.player.reset()
+                    self.player = None
+                
             else:
                 event.ignore()
         
@@ -652,7 +676,7 @@ def run():
     
     mainApp = Gui(app)
     mainApp.show()
-    
+
     try:
         app.exec_()
     except KeyboardInterrupt:
